@@ -1,6 +1,8 @@
+from typing import Dict
+
 from tabledbmapper.logger import Logger
 
-from tabledbmapper.engine import TemplateEngine
+from tabledbmapper.engine import TemplateEngine, QueryResult, CountResult, ExecResult
 from tabledbmapper.manager.manager import Manager
 from tabledbmapper.manager.xml_config import parse_config_from_string, parse_config_from_file
 
@@ -95,3 +97,12 @@ class SQLSession:
         :return: TemplateEngine
         """
         return self._engine
+
+    def query(self, sql_template: str, parameter: Dict) -> QueryResult:
+        return self._engine.query(sql_template, parameter)
+
+    def count(self, sql_template: str, parameter: Dict) -> CountResult:
+        return self._engine.count(sql_template, parameter)
+
+    def exec(self, sql_template: str, parameter: Dict) -> ExecResult:
+        return self._engine.exec(sql_template, parameter)
